==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTaskDownloadDialog.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTaskDownloadDialog<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _32_1_01690775628 _32_1_01690775628;
	public TaskDownloadDialog._32_1_01690775628. _33_2_0491900015 _33_2_0491900015;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. _34_3_1317063330 _34_3_1317063330;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. Format format;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Pdf pdf;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Csv csv;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Xls xls;
	public TaskDownloadDialog._32_1_01690775628. ColumnsBlock columnsBlock;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. ColumnModeSelector columnModeSelector;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. AllColumns allColumns;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. CustomColumns customColumns;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. CustomColumnsBlock customColumnsBlock;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.CustomColumnsBlock. Options options;
	public _44_1_1955995399 _44_1_1955995399;
	public _45_1_1190598040 _45_1_1190598040;
	public TaskDownloadDialog._45_1_1190598040. DownloadCancel downloadCancel;
	public TaskDownloadDialog._45_1_1190598040. DownloadAccept downloadAccept;

    public AbstractTaskDownloadDialog(B box) {
        super(box);
        id("TaskDownloadDialog");
    }

    @Override
	public void init() {
		super.init();
		if (_32_1_01690775628 == null) _32_1_01690775628 = register(new _32_1_01690775628(box()).<_32_1_01690775628>id("a1983267897").owner(AbstractTaskDownloadDialog.this));
		if (_32_1_01690775628 != null) _33_2_0491900015 = _32_1_01690775628._33_2_0491900015;
		if (_33_2_0491900015 != null) _34_3_1317063330 = _32_1_01690775628._33_2_0491900015._34_3_1317063330;
		if (_33_2_0491900015 != null) format = _32_1_01690775628._33_2_0491900015.format;
		if (format != null) pdf = _32_1_01690775628._33_2_0491900015.format.pdf;
		if (format != null) csv = _32_1_01690775628._33_2_0491900015.format.csv;
		if (format != null) xls = _32_1_01690775628._33_2_0491900015.format.xls;
		if (_32_1_01690775628 != null) columnsBlock = _32_1_01690775628.columnsBlock;
		if (columnsBlock != null) columnModeSelector = _32_1_01690775628.columnsBlock.columnModeSelector;
		if (columnModeSelector != null) allColumns = _32_1_01690775628.columnsBlock.columnModeSelector.allColumns;
		if (columnModeSelector != null) customColumns = _32_1_01690775628.columnsBlock.columnModeSelector.customColumns;
		if (columnsBlock != null) customColumnsBlock = _32_1_01690775628.columnsBlock.customColumnsBlock;
		if (customColumnsBlock != null) options = _32_1_01690775628.columnsBlock.customColumnsBlock.options;
		if (_44_1_1955995399 == null) _44_1_1955995399 = register(new _44_1_1955995399(box()).<_44_1_1955995399>id("a_840867489").owner(AbstractTaskDownloadDialog.this));
		if (_45_1_1190598040 == null) _45_1_1190598040 = register(new _45_1_1190598040(box()).<_45_1_1190598040>id("a_1647366937").owner(AbstractTaskDownloadDialog.this));
		if (_45_1_1190598040 != null) downloadCancel = _45_1_1190598040.downloadCancel;
		if (_45_1_1190598040 != null) downloadAccept = _45_1_1190598040.downloadAccept;
	}

	public class _32_1_01690775628 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskDownloadDialog._32_1_01690775628. _33_2_0491900015 _33_2_0491900015;
		public TaskDownloadDialog._32_1_01690775628. ColumnsBlock columnsBlock;

		public _32_1_01690775628(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_33_2_0491900015 == null) _33_2_0491900015 = register(new _33_2_0491900015(box()).<_33_2_0491900015>id("a_687905351").owner(AbstractTaskDownloadDialog.this));
			if (columnsBlock == null) columnsBlock = register(new ColumnsBlock(box()).<ColumnsBlock>id("a_146274139").owner(AbstractTaskDownloadDialog.this));
		}

		public class _33_2_0491900015 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. _34_3_1317063330 _34_3_1317063330;
			public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. Format format;

			public _33_2_0491900015(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_34_3_1317063330 == null) _34_3_1317063330 = register(new _34_3_1317063330(box()).<_34_3_1317063330>id("a_1138891799").owner(AbstractTaskDownloadDialog.this));
				if (format == null) format = register(new Format(box()).<Format>id("a_1798054998").owner(AbstractTaskDownloadDialog.this));
			}

			public class _34_3_1317063330 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _34_3_1317063330(B box) {
					super(box);
					_value("Indique el formato de descarga");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Format extends io.intino.alexandria.ui.displays.components.SelectorComboBox<io.intino.alexandria.ui.displays.notifiers.SelectorComboBoxNotifier, B>  {
				public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Pdf pdf;
				public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Csv csv;
				public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Xls xls;

				public Format(B box) {
					super(box);
					_multipleSelection(false);
				}

				@Override
				public void init() {
					super.init();
					if (pdf == null) pdf = register(new Pdf(box()).<Pdf>id("a183949021").owner(AbstractTaskDownloadDialog.this));
					if (csv == null) csv = register(new Csv(box()).<Csv>id("a183937009").owner(AbstractTaskDownloadDialog.this));
					if (xls == null) xls = register(new Xls(box()).<Xls>id("a183956970").owner(AbstractTaskDownloadDialog.this));
				}

				public class Pdf extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public Pdf(B box) {
						super(box);

						name("pdf");
						_value("Formato de documento portátil (pdf)");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class Csv extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public Csv(B box) {
						super(box);

						name("csv");
						_value("Valores separados por coma (csv)");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class Xls extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public Xls(B box) {
						super(box);

						name("xls");
						_value("Documento de Excel (xls)");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}
		}

		public class ColumnsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. ColumnModeSelector columnModeSelector;
			public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. CustomColumnsBlock customColumnsBlock;

			public ColumnsBlock(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (columnModeSelector == null) columnModeSelector = register(new ColumnModeSelector(box()).<ColumnModeSelector>id("a_1766097166").owner(AbstractTaskDownloadDialog.this));
				if (customColumnsBlock == null) customColumnsBlock = register(new CustomColumnsBlock(box()).<CustomColumnsBlock>id("a766658203").owner(AbstractTaskDownloadDialog.this));
			}

			public class ColumnModeSelector extends io.intino.alexandria.ui.displays.components.SelectorRadioBox<io.intino.alexandria.ui.displays.notifiers.SelectorRadioBoxNotifier, B>  {
				public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. AllColumns allColumns;
				public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. CustomColumns customColumns;

				public ColumnModeSelector(B box) {
					super(box);
					label("Indique las columnas de la cabecera del documento");
					_multipleSelection(false);
				}

				@Override
				public void init() {
					super.init();
					if (allColumns == null) allColumns = register(new AllColumns(box()).<AllColumns>id("a_132367767").owner(AbstractTaskDownloadDialog.this));
					if (customColumns == null) customColumns = register(new CustomColumns(box()).<CustomColumns>id("a_373336929").owner(AbstractTaskDownloadDialog.this));
				}

				public class AllColumns extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public AllColumns(B box) {
						super(box);

						name("allColumns");
						_value("Todas las columnas");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class CustomColumns extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public CustomColumns(B box) {
						super(box);

						name("customColumns");
						_value("Seleccionar las columnas del documento");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class CustomColumnsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.CustomColumnsBlock. Options options;

				public CustomColumnsBlock(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (options == null) options = register(new Options((UnitBox)box()).<Options>id("a428976378").owner(AbstractTaskDownloadDialog.this));
				}

				public class Options extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,DownloadDialogOption, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,DownloadDialogOption, java.lang.Void> {

					public Options(UnitBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public DownloadDialogOption add(java.lang.Void value) {
						DownloadDialogOption child = new DownloadDialogOption(box());
						child.id(java.util.UUID.randomUUID().toString());
						add(child, "options");
					    notifyAdd(child);
						return child;
					}
					@Override
					public void remove(DownloadDialogOption child) {
						removeChild(child, "options");
					}
					public void clear() {
					    super.clear("options");
					}
				}
			}
		}
	}

	public class _44_1_1955995399 extends io.intino.alexandria.ui.displays.components.Divider<io.intino.alexandria.ui.displays.notifiers.DividerNotifier, B>  {

		public _44_1_1955995399(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _45_1_1190598040 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskDownloadDialog._45_1_1190598040. DownloadCancel downloadCancel;
		public TaskDownloadDialog._45_1_1190598040. DownloadAccept downloadAccept;

		public _45_1_1190598040(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (downloadCancel == null) downloadCancel = register(new DownloadCancel(box()).<DownloadCancel>id("a_1760942603").owner(AbstractTaskDownloadDialog.this));
			if (downloadAccept == null) downloadAccept = register(new DownloadAccept(box()).<DownloadAccept>id("a_1816679293").owner(AbstractTaskDownloadDialog.this));
		}

		public class DownloadCancel extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

			public DownloadCancel(B box) {
				super(box);
				_title("Cancelar");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class DownloadAccept extends io.intino.alexandria.ui.displays.components.Download<io.intino.alexandria.ui.displays.notifiers.DownloadNotifier, B>  {

			public DownloadAccept(B box) {
				super(box);
				_title("Aceptar");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTaskDownloadDialog.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTaskDownloadDialog<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _32_1_01690775628 _32_1_01690775628;
	public TaskDownloadDialog._32_1_01690775628. _33_2_0491900015 _33_2_0491900015;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. _34_3_1317063330 _34_3_1317063330;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. Format format;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Pdf pdf;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Csv csv;
	public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Xls xls;
	public TaskDownloadDialog._32_1_01690775628. ColumnsBlock columnsBlock;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. ColumnModeSelector columnModeSelector;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. AllColumns allColumns;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. CustomColumns customColumns;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. CustomColumnsBlock customColumnsBlock;
	public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.CustomColumnsBlock. Options options;
	public _44_1_1955995399 _44_1_1955995399;
	public _45_1_1190598040 _45_1_1190598040;
	public TaskDownloadDialog._45_1_1190598040. DownloadCancel downloadCancel;
	public TaskDownloadDialog._45_1_1190598040. DownloadAccept downloadAccept;

    public AbstractTaskDownloadDialog(B box) {
        super(box);
        id("TaskDownloadDialog");
    }

    @Override
	public void init() {
		super.init();
		if (_32_1_01690775628 == null) _32_1_01690775628 = register(new _32_1_01690775628(box()).<_32_1_01690775628>id("a1983267897").owner(AbstractTaskDownloadDialog.this));
		if (_32_1_01690775628 != null) _33_2_0491900015 = _32_1_01690775628._33_2_0491900015;
		if (_33_2_0491900015 != null) _34_3_1317063330 = _32_1_01690775628._33_2_0491900015._34_3_1317063330;
		if (_33_2_0491900015 != null) format = _32_1_01690775628._33_2_0491900015.format;
		if (format != null) pdf = _32_1_01690775628._33_2_0491900015.format.pdf;
		if (format != null) csv = _32_1_01690775628._33_2_0491900015.format.csv;
		if (format != null) xls = _32_1_01690775628._33_2_0491900015.format.xls;
		if (_32_1_01690775628 != null) columnsBlock = _32_1_01690775628.columnsBlock;
		if (columnsBlock != null) columnModeSelector = _32_1_01690775628.columnsBlock.columnModeSelector;
		if (columnModeSelector != null) allColumns = _32_1_01690775628.columnsBlock.columnModeSelector.allColumns;
		if (columnModeSelector != null) customColumns = _32_1_01690775628.columnsBlock.columnModeSelector.customColumns;
		if (columnsBlock != null) customColumnsBlock = _32_1_01690775628.columnsBlock.customColumnsBlock;
		if (customColumnsBlock != null) options = _32_1_01690775628.columnsBlock.customColumnsBlock.options;
		if (_44_1_1955995399 == null) _44_1_1955995399 = register(new _44_1_1955995399(box()).<_44_1_1955995399>id("a_840867489").owner(AbstractTaskDownloadDialog.this));
		if (_45_1_1190598040 == null) _45_1_1190598040 = register(new _45_1_1190598040(box()).<_45_1_1190598040>id("a_1647366937").owner(AbstractTaskDownloadDialog.this));
		if (_45_1_1190598040 != null) downloadCancel = _45_1_1190598040.downloadCancel;
		if (_45_1_1190598040 != null) downloadAccept = _45_1_1190598040.downloadAccept;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_32_1_01690775628 != null) _32_1_01690775628.unregister();
	    if (_44_1_1955995399 != null) _44_1_1955995399.unregister();
	    if (_45_1_1190598040 != null) _45_1_1190598040.unregister();
	}

	public class _32_1_01690775628 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskDownloadDialog._32_1_01690775628. _33_2_0491900015 _33_2_0491900015;
		public TaskDownloadDialog._32_1_01690775628. ColumnsBlock columnsBlock;

		public _32_1_01690775628(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_33_2_0491900015 == null) _33_2_0491900015 = register(new _33_2_0491900015(box()).<_33_2_0491900015>id("a_687905351").owner(AbstractTaskDownloadDialog.this));
			if (columnsBlock == null) columnsBlock = register(new ColumnsBlock(box()).<ColumnsBlock>id("a_146274139").owner(AbstractTaskDownloadDialog.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_33_2_0491900015 != null) _33_2_0491900015.unregister();
			if (columnsBlock != null) columnsBlock.unregister();
		}

		public class _33_2_0491900015 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. _34_3_1317063330 _34_3_1317063330;
			public TaskDownloadDialog._32_1_01690775628._33_2_0491900015. Format format;

			public _33_2_0491900015(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_34_3_1317063330 == null) _34_3_1317063330 = register(new _34_3_1317063330(box()).<_34_3_1317063330>id("a_1138891799").owner(AbstractTaskDownloadDialog.this));
				if (format == null) format = register(new Format(box()).<Format>id("a_1798054998").owner(AbstractTaskDownloadDialog.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_34_3_1317063330 != null) _34_3_1317063330.unregister();
				if (format != null) format.unregister();
			}

			public class _34_3_1317063330 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _34_3_1317063330(B box) {
					super(box);
					_value("Indique el formato de descarga");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class Format extends io.intino.alexandria.ui.displays.components.SelectorComboBox<io.intino.alexandria.ui.displays.notifiers.SelectorComboBoxNotifier, B>  {
				public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Pdf pdf;
				public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Csv csv;
				public TaskDownloadDialog._32_1_01690775628._33_2_0491900015.Format. Xls xls;

				public Format(B box) {
					super(box);
					_multipleSelection(false);
				}

				@Override
				public void init() {
					super.init();
					if (pdf == null) pdf = register(new Pdf(box()).<Pdf>id("a183949021").owner(AbstractTaskDownloadDialog.this));
					if (csv == null) csv = register(new Csv(box()).<Csv>id("a183937009").owner(AbstractTaskDownloadDialog.this));
					if (xls == null) xls = register(new Xls(box()).<Xls>id("a183956970").owner(AbstractTaskDownloadDialog.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (pdf != null) pdf.unregister();
					if (csv != null) csv.unregister();
					if (xls != null) xls.unregister();
				}

				public class Pdf extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public Pdf(B box) {
						super(box);

						name("pdf");
						_value("Formato de documento portátil (pdf)");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class Csv extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public Csv(B box) {
						super(box);

						name("csv");
						_value("Valores separados por coma (csv)");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class Xls extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public Xls(B box) {
						super(box);

						name("xls");
						_value("Documento de Excel (xls)");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}
		}

		public class ColumnsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. ColumnModeSelector columnModeSelector;
			public TaskDownloadDialog._32_1_01690775628.ColumnsBlock. CustomColumnsBlock customColumnsBlock;

			public ColumnsBlock(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (columnModeSelector == null) columnModeSelector = register(new ColumnModeSelector(box()).<ColumnModeSelector>id("a_1766097166").owner(AbstractTaskDownloadDialog.this));
				if (customColumnsBlock == null) customColumnsBlock = register(new CustomColumnsBlock(box()).<CustomColumnsBlock>id("a766658203").owner(AbstractTaskDownloadDialog.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (columnModeSelector != null) columnModeSelector.unregister();
				if (customColumnsBlock != null) customColumnsBlock.unregister();
			}

			public class ColumnModeSelector extends io.intino.alexandria.ui.displays.components.SelectorRadioBox<io.intino.alexandria.ui.displays.notifiers.SelectorRadioBoxNotifier, B>  {
				public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. AllColumns allColumns;
				public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.ColumnModeSelector. CustomColumns customColumns;

				public ColumnModeSelector(B box) {
					super(box);
					label("Indique las columnas de la cabecera del documento");
					_multipleSelection(false);
				}

				@Override
				public void init() {
					super.init();
					if (allColumns == null) allColumns = register(new AllColumns(box()).<AllColumns>id("a_132367767").owner(AbstractTaskDownloadDialog.this));
					if (customColumns == null) customColumns = register(new CustomColumns(box()).<CustomColumns>id("a_373336929").owner(AbstractTaskDownloadDialog.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (allColumns != null) allColumns.unregister();
					if (customColumns != null) customColumns.unregister();
				}

				public class AllColumns extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public AllColumns(B box) {
						super(box);

						name("allColumns");
						_value("Todas las columnas");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class CustomColumns extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B> implements io.intino.alexandria.ui.displays.components.selector.SelectorOption {

					public CustomColumns(B box) {
						super(box);

						name("customColumns");
						_value("Seleccionar las columnas del documento");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class CustomColumnsBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public TaskDownloadDialog._32_1_01690775628.ColumnsBlock.CustomColumnsBlock. Options options;

				public CustomColumnsBlock(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (options == null) options = register(new Options((UnitBox)box()).<Options>id("a428976378").owner(AbstractTaskDownloadDialog.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (options != null) options.unregister();
				}

				public class Options extends io.intino.alexandria.ui.displays.components.Multiple<UnitBox,DownloadDialogOption, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<UnitBox,DownloadDialogOption, java.lang.Void> {

					public Options(UnitBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}

					@Override
					public DownloadDialogOption add(java.lang.Void value) {
						DownloadDialogOption child = new DownloadDialogOption(box());
						child.id(java.util.UUID.randomUUID().toString());
						add(child, "options");
					    notifyAdd(child);
						return child;
					}
					@Override
					public void remove(DownloadDialogOption child) {
						removeChild(child, "options");
					}
					public void clear() {
					    super.clear("options");
					}
				}
			}
		}
	}

	public class _44_1_1955995399 extends io.intino.alexandria.ui.displays.components.Divider<io.intino.alexandria.ui.displays.notifiers.DividerNotifier, B>  {

		public _44_1_1955995399(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class _45_1_1190598040 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public TaskDownloadDialog._45_1_1190598040. DownloadCancel downloadCancel;
		public TaskDownloadDialog._45_1_1190598040. DownloadAccept downloadAccept;

		public _45_1_1190598040(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (downloadCancel == null) downloadCancel = register(new DownloadCancel(box()).<DownloadCancel>id("a_1760942603").owner(AbstractTaskDownloadDialog.this));
			if (downloadAccept == null) downloadAccept = register(new DownloadAccept(box()).<DownloadAccept>id("a_1816679293").owner(AbstractTaskDownloadDialog.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (downloadCancel != null) downloadCancel.unregister();
			if (downloadAccept != null) downloadAccept.unregister();
		}

		public class DownloadCancel extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

			public DownloadCancel(B box) {
				super(box);
				_title("Cancelar");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class DownloadAccept extends io.intino.alexandria.ui.displays.components.Download<io.intino.alexandria.ui.displays.notifiers.DownloadNotifier, B>  {

			public DownloadAccept(B box) {
				super(box);
				_title("Aceptar");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
